@@ -274,15 +274,12 @@ impl<L: NetworkListener + Send + 'static> Server<L> {
                                         let keep_alive = w.handle_connection(&mut stream);
                                         stream.wait_io();
                                         if keep_alive == false {
-                                            if now.elapsed() >= timeout {
-                                                return;
-                                            } else {
-                                                yield_now();
-                                                continue;
-                                            }
+                                            return;
                                         } else {
                                             if now.elapsed() <= timeout {
                                                 now = std::time::Instant::now();
+                                            }else{
+                                                return;
                                             }
                                         }
                                     }
@@ -294,6 +291,8 @@ impl<L: NetworkListener + Send + 'static> Server<L> {
                                         let keep_alive = w.handle_connection(&mut stream);
                                         stream.wait_io();
                                         if keep_alive == false {
+                                            return;
+                                        }else{
                                             count += 1;
                                             if count >= total {
                                                 return;
@@ -369,14 +368,14 @@ impl<H: Handler + 'static> Worker<H> {
         };
         //safety will forget copy s
         let mut s: S = unsafe { std::mem::transmute_copy(stream) };
-        let stream2: &mut dyn NetworkStream = &mut s;
-        let mut rdr = BufReader::new(stream2);
+        let mut rdr = BufReader::new(&mut s as &mut dyn NetworkStream);
         let mut wrt = BufWriter::new(stream);
 
-        let mut keep_alive = false;
-        if self.keep_alive_loop(&mut rdr, &mut wrt, addr) {
+        let mut keep_alive = self.timeouts.keep_alive.is_some();
+        while self.keep_alive_loop(&mut rdr, &mut wrt, addr) {
             if let Err(e) = self.set_read_timeout(*rdr.get_ref(), self.timeouts.keep_alive) {
                 info!("set_read_timeout keep_alive {:?}", e);
+                break;
             }
             keep_alive = true;
         }
